@@ -8,13 +8,13 @@ import shortuuid
 from methodtools import lru_cache
 from multipart.multipart import parse_options_header
 from sherpa_client.api.annotate import (
-    annotate_format_binary_with_plan_ref,
-    annotate_binary_with_plan_ref,
-    annotate_documents_with,
-    annotate_format_documents_with_plan_ref,
-    annotate_format_text_with_plan_ref,
-    annotate_text_with,
-    annotate_corpus_with, annotate_binary,
+    annotate_format_binary_with_project_annotator,
+    annotate_binary_with_project_annotator,
+    annotate_documents_with_project_annotator,
+    annotate_format_documents_with_project_annotator,
+    annotate_format_text_with_project_annotator,
+    annotate_text_with_project_annotator,
+    annotate_corpus_with, annotate_binary_with_plan,
 )
 from sherpa_client.api.annotators import get_annotators_by_type
 from sherpa_client.api.documents import export_documents_sample, launch_document_import
@@ -29,7 +29,7 @@ from sherpa_client.models import (
     RequestJwtTokenProjectAccessMode,
     AnnotatorMultimap,
     WithAnnotator,
-    AnnotateFormatBinaryWithPlanRefMultipartData,
+    AnnotateFormatBinaryWithProjectAnnotatorMultipartData,
     InputDocument,
     AnnotatedDocument,
     NamedAnnotationPlan,
@@ -42,7 +42,7 @@ from sherpa_client.models import (
     ProjectConfigCreation,
     ProjectStatus,
     LaunchDocumentImportMultipartData, AnnotateBinaryForm, Converter, ConvertAnnotationPlan,
-    LaunchDocumentImportSegmentationPolicy, ShareMode,
+    LaunchDocumentImportSegmentationPolicy, ShareMode, AnnotateBinaryWithProjectAnnotatorMultipartData,
 )
 from sherpa_client.types import File, Unset, UNSET, Response
 from streamlit.uploaded_file_manager import UploadedFile
@@ -343,7 +343,7 @@ class StreamlitSherpaClient:
             annotator.name if isinstance(annotator, ExtendedAnnotator) else annotator
         )
         long_client = self.client.with_timeout(1000)
-        r = annotate_text_with.sync_detailed(
+        r = annotate_text_with_project_annotator.sync_detailed(
             pname, aname, text_body=text, client=long_client
         )
         # r = annotate_documents_with.sync_detailed(pname, aname,
@@ -379,8 +379,8 @@ class StreamlitSherpaClient:
             annotator.name if isinstance(annotator, ExtendedAnnotator) else annotator
         )
         long_client = self.client.with_timeout(1000)
-        r = annotate_format_text_with_plan_ref.sync_detailed(
-            pname, aname, text_body=text, client=long_client
+        r = annotate_format_text_with_project_annotator.sync_detailed(
+            pname, aname, text_body=text, client=long_client, parallelize=True
         )
         # r = annotate_format_documents_with_plan_ref.sync_detailed(pname, aname,
         #                                                           json_body=[InputDocument(text=text)],
@@ -400,7 +400,7 @@ class StreamlitSherpaClient:
         aname = (
             annotator.name if isinstance(annotator, ExtendedAnnotator) else annotator
         )
-        files = AnnotateFormatBinaryWithPlanRefMultipartData(
+        files = AnnotateBinaryWithProjectAnnotatorMultipartData(
             file=File(
                 file_name=datafile.name,
                 payload=datafile.getvalue(),
@@ -408,7 +408,7 @@ class StreamlitSherpaClient:
             )
         )
         long_client = self.client.with_timeout(1000)
-        r = annotate_binary_with_plan_ref.sync_detailed(
+        r = annotate_binary_with_project_annotator.sync_detailed(
             pname, aname, multipart_data=files, client=long_client
         )
         if r.is_success:
@@ -427,7 +427,7 @@ class StreamlitSherpaClient:
         aname = (
             annotator.name if isinstance(annotator, ExtendedAnnotator) else annotator
         )
-        files = AnnotateFormatBinaryWithPlanRefMultipartData(
+        files = AnnotateFormatBinaryWithProjectAnnotatorMultipartData(
             file=File(
                 file_name=datafile.name,
                 payload=datafile.getvalue(),
@@ -435,8 +435,8 @@ class StreamlitSherpaClient:
             )
         )
         long_client = self.client.with_timeout(1000)
-        r = annotate_format_binary_with_plan_ref.sync_detailed(
-            pname, aname, multipart_data=files, client=long_client
+        r = annotate_format_binary_with_project_annotator.sync_detailed(
+            pname, aname, multipart_data=files, client=long_client, parallelize=True
         )
         if r.is_success:
             return self._file_from_response(r)
@@ -467,7 +467,7 @@ class StreamlitSherpaClient:
             plan=plan
         )
         long_client = self.client.with_timeout(1000)
-        r = annotate_binary.sync_detailed(
+        r = annotate_binary_with_plan.sync_detailed(
             multipart_data=files, client=long_client
         )
         if r.is_success:
@@ -515,8 +515,8 @@ class StreamlitSherpaClient:
             InputDocument.from_dict(doc) for doc in self.documents_from_file(datafile)
         ]
         long_client = self.client.with_timeout(1000)
-        r = annotate_documents_with.sync_detailed(
-            pname, aname, json_body=documents, client=long_client
+        r = annotate_documents_with_project_annotator.sync_detailed(
+            pname, aname, json_body=documents, client=long_client, parallelize=True
         )
         if r.is_success:
             docs = r.parsed
@@ -538,8 +538,8 @@ class StreamlitSherpaClient:
             InputDocument.from_dict(doc) for doc in self.documents_from_file(datafile)
         ]
         long_client = self.client.with_timeout(1000)
-        r = annotate_format_documents_with_plan_ref.sync_detailed(
-            pname, aname, json_body=documents, client=long_client
+        r = annotate_format_documents_with_project_annotator.sync_detailed(
+            pname, aname, json_body=documents, client=long_client, parallelize=True
         )
         if r.is_success:
             return self._file_from_response(r)
